<?php
if ( ! function_exists( 'hotelone_get_layout' ) ) {

    function hotelone_get_layout( $default = 'right' ) {

        $layout = get_theme_mod( 'hotelone_layout', 'right' );
        return apply_filters( 'hotelone_get_layout', $layout, $default );

    }
    
}

if ( ! function_exists( 'hotelone_get_media_url' ) ) {

    function hotelone_get_media_url($media = array(), $size = 'full' ) {

        $media = wp_parse_args( $media, array('url' => '', 'id' => ''));
        $url = '';
        if ($media['id'] != '') {
            if ( strpos( get_post_mime_type( $media['id'] ), 'image' ) !== false ) {
                $image = wp_get_attachment_image_src( $media['id'],  $size );
                if ( $image ){
                    $url = $image[0];
                }
            } else {
                $url = wp_get_attachment_url( $media['id'] );
            }
        }

        if ($url == '' && $media['url'] != '') {
            $id = attachment_url_to_postid( $media['url'] );
            if ( $id ) {
                if ( strpos( get_post_mime_type( $id ), 'image' ) !== false ) {
                    $image = wp_get_attachment_image_src( $id,  $size );
                    if ( $image ){
                        $url = $image[0];
                    }
                } else {
                    $url = wp_get_attachment_url( $id );
                }
            } else {
                $url = $media['url'];
            }
        }
        return $url;
    }
}

/**
 * Custom excerpt length
 */
if ( ! function_exists( 'hotelone_custom_excerpt_length' ) ) :

    add_filter( 'excerpt_length', 'hotelone_custom_excerpt_length', 100 );

    function hotelone_custom_excerpt_length( $length ) {
    	
    	global $post;

    	if( 
            $post->post_type == 'room' || 
            $post->post_type == 'event' ||
            $post->post_type == 'recipe'
        ){

    		return 10;

    	}

        $excerpt_length = get_theme_mod('archive_excerpt_length', 15 );

    	return absint( apply_filters( 'hotelone_excerpt_length', $excerpt_length ) );
    }

endif;

/**
 * Remove […]
 */
if ( ! function_exists( 'hotelone_new_excerpt_more' ) ) :

    add_filter('excerpt_more', 'hotelone_new_excerpt_more', 15 );

    function hotelone_new_excerpt_more( $more ) {
    	
        $service_more_text = get_theme_mod( 'hotelone_service_more_text', __('Read More','hotelone') );

        $read_more_text = get_theme_mod( 'read_more_button_text', __('Read More','hotelone') );

    	global $post;
    	
    	if( 
            is_front_page() && 
            is_home() || 
            is_page_template('template-service.php'
        ) ){
    		$textagign = 'center';
    	}else{
    		$textagign = 'center';
    	}
 
        if( $post->post_type == 'recipe' ){
            $textagign = 'left';
        }
    	
    	if( $post->post_type == 'room' ){
    		return '...';
    	}

        if( $post->post_type == 'event' ){
            $textagign = 'center';
            return apply_filters( 'hotelone_excerpt_more_output', sprintf(
            ' ... <div class="text-'.esc_attr( $textagign ).'"><a class="theme-btn" href="%s">%1s</a></div>',
            esc_url( get_the_permalink() ),
            __('View Details','hotelone')
            ) );
        }

        if( $post->post_type == 'page' ){
            $textagign = 'center';
            return apply_filters( 'hotelone_excerpt_more_output', sprintf(
            ' ... <div class="text-'.esc_attr( $textagign ).'"><a class="theme-btn" href="%s">%1s</a></div>',
            esc_url( get_the_permalink() ),
            $service_more_text
            ) );
        }
    	
    	return apply_filters( 'hotelone_excerpt_more_output', sprintf(
    		' ... <div class="text-'.esc_attr( $textagign ).'"><a class="more-link" href="%s">%1s</a></div>',
    		esc_url( get_the_permalink() ),
    		$read_more_text
    		) );
    }

endif;

/* Content Read More */

if ( ! function_exists( 'hotelone_blog_content_more' ) ) :

    add_filter( 'the_content_more_link', 'hotelone_blog_content_more', 15 );

    function hotelone_blog_content_more( $more ) {

        $excerpt_readmore = get_theme_mod('archive_readmore_label');

        // If empty, return

        if ( '' == $excerpt_readmore ) {

            return '';

        }

        return apply_filters( 'hotelone_content_more_link_output', sprintf( '<p class="more-link-container"><a title="%1$s" class="more-link content-more-link" href="%2$s">%3$s%4$s <i class="fa fa-long-arrow-right"></i></a></p>',
            the_title_attribute( 'echo=0' ),
            esc_url( get_permalink( get_the_ID() ) . apply_filters( 'hotelone_more_jump','#more-' . get_the_ID() ) ),
            wp_kses_post( $excerpt_readmore ),
            '<span class="screen-reader-text">' . get_the_title() . '</span>'
        ) );

    }

endif;

add_filter( 'hotelone_excerpt_more_output', 'hotelone_blog_read_more_button' );
add_filter( 'hotelone_content_more_link_output', 'hotelone_blog_read_more_button' );

function hotelone_blog_read_more_button( $output ) {

    $archive_readmore_button = get_theme_mod('archive_readmore_label');

    $excerpt_readmore = get_theme_mod('archive_readmore_label');

    $archive_readmore_button = get_theme_mod('archive_readmore_button');

    $class='';

    if($archive_readmore_button){

        $class = 'button';

    }

    if ( !$archive_readmore_button ) {

        return $output;

    }

    return sprintf( '%5$s<p class="more-link-container"><a title="%1$s" class="more-link %6$s" href="%2$s">%3$s%4$s <i class="fa fa-long-arrow-right"></i></a></p>',
        the_title_attribute( 'echo=0' ),
        esc_url( get_permalink( get_the_ID() ) . apply_filters( 'hotelone_more_jump','#more-' . get_the_ID() ) ),
        wp_kses_post( $excerpt_readmore ),
        '<span class="screen-reader-text">' . get_the_title() . '</span>',
        'hotelone_excerpt_more_output' == current_filter() ? ' ... ' : '',
        esc_attr($class)
    );

}

class Hotelone_Extra_Activator {

    public static function activate() {

        $home_and_blog_activate = get_option( 'home_and_blog_activate' );
        
        if ( (bool) $home_and_blog_activate === false ) {

                    $pages = array( 
                        esc_html__( 'Home', 'hotelone' ), 
                        esc_html__( 'Blog', 'hotelone' ) 
                    );

                    foreach ($pages as $page){ 

                        $post_data = array( 
                            'post_author' => 1, 
                            'post_name' => $page,  
                            'post_status' => 'publish' , 
                            'post_title' => $page, 
                            'post_type' => 'page', 
                        );  
                        
                        if($page== 'Home'): 
                            $page_option = 'page_on_front';
                            $template = 'template-homepage.php'; 
                        else:   
                            $page_option = 'page_for_posts';
                            $template = 'page.php';
                        endif;

                        $post_data = wp_insert_post( $post_data, false );

                            if ( $post_data ){
                                update_post_meta( $post_data, '_wp_page_template', $template );
                                $page = get_page_by_title($page);
                                update_option( 'show_on_front', 'page' );
                                update_option( $page_option, $page->ID );
                            }
                    }
                    
            update_option( 'home_and_blog_activate', true );                   
        }   
    }
}
Hotelone_Extra_Activator::activate();